@@ -13,17 +13,13 @@ from .fb_types import URL, Page, RawPage, RequestFunction, Response
 
 logger = logging.getLogger(__name__)
 
-
-class StartURLNotFound(Exception):
-    pass
-
-
 def iter_pages(account: str, request_fn: RequestFunction) -> Iterator[Page]:
-    start_url = utils.urljoin(FB_MOBILE_BASE_URL, f'/{account}/')
+    start_url = utils.urljoin(FB_MOBILE_BASE_URL, f'/{account}/posts/')
     try:
-        return generic_iter_pages(start_url + 'posts/', PageParser, request_fn)
-    except StartURLNotFound:
-        return generic_iter_pages(start_url, PageParser, request_fn)
+        request_fn(start_url)
+    except HTTPError as ex:
+        start_url = utils.urljoin(FB_MOBILE_BASE_URL, f'/{account}/')
+    return generic_iter_pages(start_url, PageParser, request_fn)
 
 
 def iter_group_pages(group: Union[str, int], request_fn: RequestFunction) -> Iterator[Page]:
@@ -36,12 +32,7 @@ def generic_iter_pages(start_url, page_parser_cls, request_fn: RequestFunction)
 
     while next_url:
         logger.debug("Requesting page from: %s", next_url)
-        try:
-            response = request_fn(next_url)
-        except HTTPError as ex:
-            if ex.response and ex.response.status_code == 404 and next_url == start_url:
-                raise StartURLNotFound from ex
-            raise
+        response = request_fn(next_url)
 
         logger.debug("Parsing page response")
         parser = page_parser_cls(response)
